@@ -1937,7 +1937,7 @@ void folder_clean_cache_memory(void)
 		while((listitem != NULL) && (memusage > (prefs_common.cache_max_mem_usage * 1024))) {
 			FolderItem *item = (FolderItem *)(listitem->data);
 
-			debug_print("Freeing cache memory for %s\n", item->path);
+			debug_print("Freeing cache memory for %s\n", item->path ? item->path : item->name);
 			memusage -= msgcache_get_memory_usage(item->cache);
 		        folder_item_free_cache(item);
 			listitem = listitem->next;
@@ -2087,7 +2087,9 @@ static void msginfo_set_mime_flags(GNode *node, gpointer data)
 	} else if (mimeinfo->disposition == DISPOSITIONTYPE_UNKNOWN && 
 		 mimeinfo->type != MIMETYPE_TEXT &&
 		 mimeinfo->type != MIMETYPE_MULTIPART) {
-		procmsg_msginfo_set_flags(msginfo, 0, MSG_HAS_ATTACHMENT);
+		if (!mimeinfo->subtype 
+		||  strcmp(mimeinfo->subtype, "pgp-signature"))
+			procmsg_msginfo_set_flags(msginfo, 0, MSG_HAS_ATTACHMENT);
 	}
 
 	/* don't descend below top level message for signed and encrypted info */
@@ -2786,7 +2788,10 @@ gint folder_item_remove_msgs(FolderItem *item, GSList *msglist)
 	folder_item_update_freeze();
 	while (msglist != NULL) {
 		MsgInfo *msginfo = (MsgInfo *)msglist->data;
-
+		if (MSG_IS_LOCKED(msginfo->flags)) {
+			msglist = msglist->next;
+			continue;
+		}
 		ret = folder_item_remove_msg(item, msginfo->msgnum);
 		if (ret != 0) break;
 		msgcache_remove_msg(item->cache, msginfo->msgnum);
