@@ -236,15 +236,15 @@ GHashTable *folderview_popups;
 
 static GtkItemFactoryEntry folderview_common_popup_entries[] =
 {
-	{N_("/Mark all _read"),		NULL, mark_all_read_cb, 0, NULL},
+	{N_("/Mark all re_ad"),		NULL, mark_all_read_cb, 0, NULL},
 	{N_("/_Search folder..."),	NULL, folderview_search_cb, 0, NULL},
 	{N_("/_Properties..."),		NULL, folderview_property_cb, 0, NULL},
-	{N_("/Pr_ocessing..."),		NULL, folderview_processing_cb, 0, NULL},
+	{N_("/Process_ing..."),		NULL, folderview_processing_cb, 0, NULL},
 };
 
 static GtkItemFactoryEntry folder_view_trash_popup_entries[] = {
 	{N_("/------"),			NULL, NULL, 0, "<Separator>"},
-	{N_("/Empty trash..."),		NULL, folderview_empty_trash_cb, 0, NULL},
+	{N_("/Empty _trash..."),	NULL, folderview_empty_trash_cb, 0, NULL},
 };
 
 
@@ -1444,6 +1444,18 @@ static void folderview_button_pressed(GtkWidget *ctree, GdkEventButton *event,
 
 	if (event->button == 1) {
 		folderview->open_folder = TRUE;
+
+	        if (event->type == GDK_2BUTTON_PRESS) {
+			if (clist->selection) {
+				GtkCTreeNode *node;
+
+				node = GTK_CTREE_NODE(clist->selection->data);
+				if (node)
+					gtk_ctree_toggle_expansion(
+						GTK_CTREE(ctree),
+						node);
+			}
+		}
 		return;
 	}
 
@@ -1791,6 +1803,8 @@ static void folderview_empty_trash_cb(FolderView *folderview, guint action,
 	
 	for (cur = mlist ; cur != NULL ; cur = cur->next) {
 		MsgInfo * msginfo = (MsgInfo *) cur->data;
+		if (MSG_IS_LOCKED(msginfo->flags))
+			continue;
 		/* is it partially received? (partial_recv isn't cached) */
 		if (msginfo->total_size != 0 && 
 		    msginfo->size != (off_t)msginfo->total_size)
@@ -1860,6 +1874,22 @@ void folderview_move_folder(FolderView *folderview, FolderItem *from_folder,
 
 	src_node = gtk_ctree_find_by_row_data(GTK_CTREE(folderview->ctree), NULL, from_folder);
 	from_parent = folder_item_parent(from_folder);
+	
+	if (prefs_common.warn_dnd) {
+		buf = g_strdup_printf(_("Do you really want to move folder `%s' to a "
+					"sub-folder of `%s' ?"), from_folder->name,
+					to_folder->name);
+		status = alertpanel_message_with_disable(_("Move folder"), buf, 
+				_("Yes"), _("No"), NULL, ALERT_QUESTION);
+		g_free(buf);
+
+		if (status != G_ALERTDEFAULT
+		 && status != (G_ALERTDEFAULT | G_ALERTDISABLE))
+			return;
+		if (status & G_ALERTDISABLE)
+			prefs_common.warn_dnd = FALSE;
+	}
+
 	buf = g_strdup_printf(_("Moving %s to %s..."), from_folder->name, to_folder->name);
 	STATUSBAR_PUSH(folderview->mainwin, buf);
 	g_free(buf);
