@@ -501,6 +501,7 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 	FolderItem *processing, *inbox;
 	MsgInfo *msginfo;
 	GSList *msglist, *msglist_element;
+	gboolean cancelled = FALSE;
 
 	qlist = inc_dialog->queue_list;
 	while (qlist != NULL) {
@@ -548,7 +549,7 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 	gtk_clist_set_text(clist, inc_dialog->cur_row, 2, str);		   \
 }
 
-	for (; inc_dialog->queue_list != NULL; inc_dialog->cur_row++) {
+	for (; inc_dialog->queue_list != NULL && !cancelled; inc_dialog->cur_row++) {
 		session = inc_dialog->queue_list->data;
 		pop3_session = POP3_SESSION(session->session);
 
@@ -572,8 +573,10 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 		switch (inc_state) {
 		case INC_SUCCESS:
 			if (pop3_session->cur_total_num > 0)
-				msg = g_strdup_printf
-					(_("Done (%d message(s) (%s) received)"),
+				msg = g_strdup_printf(
+					ngettext("Done (%d message (%s) received)",
+						 "Done (%d messages (%s) received)",
+					 pop3_session->cur_total_num),
 					 pop3_session->cur_total_num,
 					 to_human_readable(pop3_session->cur_total_recv_bytes));
 			else
@@ -605,6 +608,8 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 			break;
 		case INC_CANCEL:
 			SET_PIXMAP_AND_TEXT(okxpm, okxpmmask, _("Cancelled"));
+			if (!inc_dialog->show_dialog)
+				cancelled = TRUE;
 			break;
 		default:
 			break;
@@ -636,8 +641,12 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 		/* process messages */
 		folder_item_update_freeze();
 		for(msglist_element = msglist; msglist_element != NULL; msglist_element = msglist_element->next) {
+			gchar *filename;
 			msginfo = (MsgInfo *) msglist_element->data;
-			if (!pop3_session->ac_prefs->filter_on_recv || !procmsg_msginfo_filter(msginfo))
+			filename = folder_item_fetch_msg(processing, msginfo->msgnum);
+			g_free(filename);
+			if (!pop3_session->ac_prefs->filter_on_recv || 
+			    !procmsg_msginfo_filter(msginfo))
 				folder_item_move_msg(inbox, msginfo);
 			procmsg_msginfo_free(msginfo);
 		}
@@ -680,8 +689,9 @@ static gint inc_start(IncProgressDialog *inc_dialog)
 #undef SET_PIXMAP_AND_TEXT
 
 	if (new_msgs > 0)
-		fin_msg = g_strdup_printf(_("Finished (%d new message(s))"),
-					  new_msgs);
+		fin_msg = g_strdup_printf(ngettext("Finished (%d new message)",
+					  	   "Finished (%d new messages)",
+					  	   new_msgs), new_msgs);
 	else
 		fin_msg = g_strdup_printf(_("Finished (no new messages)"));
 
@@ -932,7 +942,9 @@ static void inc_progress_dialog_set_progress(IncProgressDialog *inc_dialog,
 
 	if (pop3_session->cur_total_num > 0) {
 		g_snprintf(buf, sizeof(buf),
-			   _("Retrieving (%d message(s) (%s) received)"),
+			   ngettext("Retrieving (%d message (%s) received)",
+			   	    "Retrieving (%d messages (%s) received)",
+				    pop3_session->cur_total_num),
 			   pop3_session->cur_total_num,
 			   to_human_readable
 			   (pop3_session->cur_total_recv_bytes));
