@@ -477,6 +477,7 @@ static void exit_sylpheed(MainWindow *mainwin)
 	g_free(filename);
 
 	/* delete temporary files */
+	remove_all_files(get_tmp_dir());
 	remove_all_files(get_mime_tmp_dir());
 
 	close_log_file();
@@ -652,15 +653,12 @@ static void initial_processing(FolderItem *item, gpointer data)
 
 static void draft_all_messages(void)
 {
-	GList *compose_list = compose_get_compose_list();
+	GList *compose_list = NULL;
 	GList *elem = NULL;
 	
-	if (compose_list) {
-		for (elem = compose_list; elem != NULL && elem->data != NULL; 
-		     elem = elem->next) {
-			Compose *c = (Compose*)elem->data;
-			compose_draft(c);
-		}
+	while ((compose_list = compose_get_compose_list()) != NULL) {
+		Compose *c = (Compose*)compose_list->data;
+		compose_draft(c);
 	}	
 }
 
