@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2004 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2005 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -447,7 +447,7 @@ static GtkItemFactoryEntry mainwin_entries[] =
 	{N_("/_File/---"),			NULL, NULL, 0, "<Separator>"},
 	{N_("/_File/_Import mbox file..."),	NULL, import_mbox_cb, 0, NULL},
 	{N_("/_File/_Export to mbox file..."),	NULL, export_mbox_cb, 0, NULL},
-	{N_("/_File/_Export selected to mbox file..."),	
+	{N_("/_File/Exp_ort selected to mbox file..."),	
 						NULL, export_list_mbox_cb, 0, NULL},
 	{N_("/_File/---"),			NULL, NULL, 0, "<Separator>"},
 	{N_("/_File/Empty all _Trash folders"),	"<shift>D", empty_trash_cb, 0, NULL},
@@ -645,7 +645,7 @@ static GtkItemFactoryEntry mainwin_entries[] =
 	{N_("/_View/---"),			NULL, NULL, 0, "<Separator>"},
 	{N_("/_View/Open in new _window"),	"<control><alt>N", open_msg_cb, 0, NULL},
 	{N_("/_View/Mess_age source"),		"<control>U", view_source_cb, 0, NULL},
-	{N_("/_View/Show all _headers"),	"<control>H", show_all_header_cb, 0, "<ToggleItem>"},
+	{N_("/_View/Show all headers"),		"<control>H", show_all_header_cb, 0, "<ToggleItem>"},
 	{N_("/_View/---"),			NULL, NULL, 0, "<Separator>"},
 	{N_("/_View/_Update summary"),		"<control><alt>U", update_summary_cb,  0, NULL},
 
@@ -712,19 +712,19 @@ static GtkItemFactoryEntry mainwin_entries[] =
 						NULL, create_filter_cb, FILTER_BY_TO, NULL},
 	{N_("/_Tools/_Create filter rule/by _Subject"),
 						NULL, create_filter_cb, FILTER_BY_SUBJECT, NULL},
-	{N_("/_Tools/_Create processing rule"),	NULL, NULL, 0, "<Branch>"},
-	{N_("/_Tools/_Create processing rule/_Automatically"),
+	{N_("/_Tools/C_reate processing rule"),	NULL, NULL, 0, "<Branch>"},
+	{N_("/_Tools/C_reate processing rule/_Automatically"),
 						NULL, create_processing_cb, FILTER_BY_AUTO, NULL},
-	{N_("/_Tools/_Create processing rule/by _From"),
+	{N_("/_Tools/C_reate processing rule/by _From"),
 						NULL, create_processing_cb, FILTER_BY_FROM, NULL},
-	{N_("/_Tools/_Create processing rule/by _To"),
+	{N_("/_Tools/C_reate processing rule/by _To"),
 						NULL, create_processing_cb, FILTER_BY_TO, NULL},
-	{N_("/_Tools/_Create processing rule/by _Subject"),
+	{N_("/_Tools/C_reate processing rule/by _Subject"),
 						NULL, create_processing_cb, FILTER_BY_SUBJECT, NULL},
 	{N_("/_Tools/---"),			NULL, NULL, 0, "<Separator>"},
 	{N_("/_Tools/Actio_ns"),		NULL, NULL, 0, "<Branch>"},
 	{N_("/_Tools/---"),			NULL, NULL, 0, "<Separator>"},
-	{N_("/_Tools/_Check for new messages in all folders"),
+	{N_("/_Tools/Ch_eck for new messages in all folders"),
 						NULL, update_folderview_cb, 0, NULL},
 	{N_("/_Tools/Delete du_plicated messages"),
 						NULL, NULL, 0, "<Branch>"},
@@ -736,7 +736,7 @@ static GtkItemFactoryEntry mainwin_entries[] =
 	{N_("/_Tools/E_xecute"),		"X", execute_summary_cb, 0, NULL},
 #ifdef USE_OPENSSL
 	{N_("/_Tools/---"),			NULL, NULL, 0, "<Separator>"},
-	{N_("/_Tools/SSL certi_ficates..."),	
+	{N_("/_Tools/SSL cer_tificates..."),	
 						NULL, ssl_manager_open_cb, 0, NULL},
 #endif
 	{N_("/_Tools/---"),			NULL, NULL, 0, "<Separator>"},
@@ -752,24 +752,24 @@ static GtkItemFactoryEntry mainwin_entries[] =
 	{N_("/_Configuration/_Edit accounts..."),
 						NULL, account_edit_open, 0, NULL},
 	{N_("/_Configuration/---"),		NULL, NULL, 0, "<Separator>"},
-	{N_("/_Configuration/_Preferences..."),
+	{N_("/_Configuration/P_references..."),
 						NULL, prefs_open_cb, 0, NULL},
-	{N_("/_Configuration/Pre-processing..."),
+	{N_("/_Configuration/Pre-pr_ocessing..."),
 						NULL, prefs_pre_processing_open_cb, 0, NULL},
-	{N_("/_Configuration/Post-processing..."),
+	{N_("/_Configuration/Post-pro_cessing..."),
 						NULL, prefs_post_processing_open_cb, 0, NULL},
 	{N_("/_Configuration/_Filtering..."),
 						NULL, prefs_filtering_open_cb, 0, NULL},
 	{N_("/_Configuration/_Templates..."),	NULL, prefs_template_open_cb, 0, NULL},
 	{N_("/_Configuration/_Actions..."),	NULL, prefs_actions_open_cb, 0, NULL},
-	{N_("/_Configuration/Plugins..."),  	NULL, plugins_open_cb, 0, NULL},
+	{N_("/_Configuration/Plu_gins..."),  	NULL, plugins_open_cb, 0, NULL},
 
 	{N_("/_Help"),				NULL, NULL, 0, "<Branch>"},
 	{N_("/_Help/_Manual (Local)"),		NULL, manual_open_cb, MANUAL_MANUAL_LOCAL, NULL},
-	{N_("/_Help/_Manual (Sylpheed Doc Homepage)"),
+	{N_("/_Help/Ma_nual (Sylpheed Doc Homepage)"),
 						NULL, manual_open_cb, MANUAL_MANUAL_SYLDOC, NULL},
 	{N_("/_Help/_FAQ (Local)"),		NULL, manual_open_cb, MANUAL_FAQ_LOCAL, NULL},
-	{N_("/_Help/_FAQ (Sylpheed Doc Homepage)"),
+	{N_("/_Help/FA_Q (Sylpheed Doc Homepage)"),
 						NULL, manual_open_cb, MANUAL_FAQ_SYLDOC, NULL},
 	{N_("/_Help/_Claws FAQ (Claws Documentation)"),
 						NULL, manual_open_cb, MANUAL_FAQ_CLAWS, NULL},
@@ -2787,7 +2787,9 @@ static void delete_duplicated_all_cb(MainWindow *mainwin, guint action,
 	struct DelDupsData data = {0, 0};
 
 	folder_func_to_all_folders(deldup_all, &data);
-	alertpanel_notice(_("Deleted %d duplicate message(s) in %d folders.\n"),
+	alertpanel_notice(ngettext("Deleted %d duplicate message in %d folders.\n",
+				   "Deleted %d duplicate messages in %d folders.\n",
+				   data.dups),
 			  data.dups, data.folders);
 }
 
