@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2004 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2005 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -285,6 +285,10 @@ struct _PrefsCommon
 	gulong color_new;
 	
 	GList *summary_quicksearch_history;
+	
+	gint filteringwin_width;
+	gint filteringwin_height;
+	gint warn_dnd;
 };
 
 extern PrefsCommon prefs_common;
