@@ -178,6 +178,8 @@ static gint error = 0;
 
 static gint cursor_pos  = 0;
 
+extern int quote_fmt_firsttime;
+
 static void add_visibility(gboolean val)
 {
 	stacksize++;
@@ -249,6 +251,10 @@ void quote_fmt_init(MsgInfo *info, const gchar *my_quote_str,
 		*buffer = 0;
 	bufsize = 0;
 	error = 0;
+        /*
+         * force LEX initialization
+         */
+	quote_fmt_firsttime = 1;
 	cursor_pos = 0;
 }
 
@@ -268,6 +274,236 @@ static int isseparator(int ch)
 	return isspace(ch) || ch == '.' || ch == '-';
 }
 
+static void quote_fmt_show_date(const MsgInfo *msginfo, const gchar *format)
+{
+	char  result[100];
+	char *rptr;
+	char  zone[6];
+	struct tm lt;
+	const char *fptr;
+	const char *zptr;
+
+	if (!msginfo->date)
+		return;
+	
+	/* 
+	 * ALF - GNU C's strftime() has a nice format specifier 
+	 * for time zone offset (%z). Non-standard however, so 
+	 * emulate it.
+	 */
+
+#define RLEFT (sizeof result) - (rptr - result)	
+#define STR_SIZE(x) (sizeof (x) - 1)
+
+	zone[0] = 0;
+
+	if (procheader_date_parse_to_tm(msginfo->date, &lt, zone)) {
+		/*
+		 * break up format string in tiny bits delimited by valid %z's and 
+		 * feed it to strftime(). don't forget that '%%z' mean literal '%z'.
+		 */
+		for (rptr = result, fptr = format; fptr && *fptr && rptr < &result[sizeof result - 1];) {
+			int	    perc;
+			const char *p;
+			char	   *tmp;
+			
+			if (NULL != (zptr = strstr(fptr, "%z"))) {
+				/*
+				 * count nr. of prepended percent chars
+				 */
+				for (perc = 0, p = zptr; p && p >= format && *p == '%'; p--, perc++)
+					;
+				/*
+				 * feed to strftime()
+				 */
+				tmp = g_strndup(fptr, zptr - fptr + (perc % 2 ? 0 : STR_SIZE("%z")));
+				if (tmp) {
+					rptr += strftime(rptr, RLEFT, tmp, &lt);
+					g_free(tmp);
+				}
+				/*
+				 * append time zone offset
+				 */
+				if (zone[0] && perc % 2) 
+					rptr += g_snprintf(rptr, RLEFT, "%s", zone);
+				fptr = zptr + STR_SIZE("%z");
+			} else {
+				rptr += strftime(rptr, RLEFT, fptr, &lt);
+				fptr  = NULL;
+			}
+		}
+		
+		INSERT(result);
+	}
+#undef STR_SIZE			
+#undef RLEFT			
+}		
+
+static void quote_fmt_show_first_name(const MsgInfo *msginfo)
+{
+	guchar *p;
+	gchar *str;
+
+	if (!msginfo->fromname)
+		return;	
+	
+	p = strchr(msginfo->fromname, ',');
+	if (p != NULL) {
+		/* fromname is like "Duck, Donald" */
+		p++;
+		while (*p && isspace(*p)) p++;
+		str = alloca(strlen(p) + 1);
+		if (str != NULL) {
+			strcpy(str, p);
+			INSERT(str);
+		}
+	} else {
+		/* fromname is like "Donald Duck" */
+		str = alloca(strlen(msginfo->fromname) + 1);
+		if (str != NULL) {
+			strcpy(str, msginfo->fromname);
+			p = str;
+			while (*p && !isspace(*p)) p++;
+			*p = '\0';
+			INSERT(str);
+		}
+	}
+}
+
+static void quote_fmt_show_last_name(const MsgInfo *msginfo)
+{
+	gchar *p;
+	gchar *str;
+
+	/* This probably won't work together very well with Middle
+           names and the like - thth */
+	if (!msginfo->fromname) 
+		return;
+
+	str = alloca(strlen(msginfo->fromname) + 1);
+	if (str != NULL) {
+		strcpy(str, msginfo->fromname);
+		p = strchr(str, ',');
+		if (p != NULL) {
+			/* fromname is like "Duck, Donald" */
+			*p = '\0';
+			INSERT(str);
+		} else {
+			/* fromname is like "Donald Duck" */
+			p = str;
+			while (*p && !isspace(*p)) p++;
+			if (*p) {
+			    /* We found a space. Get first 
+			     none-space char and insert
+			     rest of string from there. */
+			    while (*p && isspace(*p)) p++;
+			    if (*p) {
+				INSERT(p);
+			    } else {
+				/* If there is no none-space 
+				 char, just insert whole 
+				 fromname. */
+				INSERT(str);
+			    }
+			} else {
+			    /* If there is no space, just 
+			     insert whole fromname. */
+			    INSERT(str);
+			}
+		}
+	}
+}
+
+static void quote_fmt_show_sender_initial(const MsgInfo *msginfo)
+{
+#define MAX_SENDER_INITIAL 20
+	gchar tmp[MAX_SENDER_INITIAL];
+	guchar *p;
+	gchar *cur;
+	gint len = 0;
+
+	if (!msginfo->fromname) 
+		return;
+
+	p = msginfo->fromname;
+	cur = tmp;
+	while (*p) {
+		if (*p && isalnum(*p)) {
+			*cur = toupper(*p);
+				cur++;
+			len++;
+			if (len >= MAX_SENDER_INITIAL - 1)
+				break;
+		} else
+			break;
+		while (*p && !isseparator(*p)) p++;
+		while (*p && isseparator(*p)) p++;
+	}
+	*cur = '\0';
+	INSERT(tmp);
+}
+
+static void quote_fmt_show_msg(MsgInfo *msginfo, const gchar *body,
+			       gboolean quoted, gboolean signature,
+			       const gchar *quote_str)
+{
+	gchar buf[BUFFSIZE];
+	FILE *fp;
+
+	if (!(msginfo->folder || body))
+		return;
+
+	if (body)
+		fp = str_open_as_stream(body);
+	else
+		fp = procmime_get_first_text_content(msginfo);
+
+	if (fp == NULL)
+		g_warning("Can't get text part\n");
+	else {
+		while (fgets(buf, sizeof(buf), fp) != NULL) {
+			strcrchomp(buf);
+			
+			if (!signature && strncmp(buf, "-- \n", 4) == 0)
+				break;
+		
+			if (quoted && quote_str)
+				INSERT(quote_str);
+			
+			INSERT(buf);
+		}
+		fclose(fp);
+	}
+}
+
+static void quote_fmt_insert_file(const gchar *filename)
+{
+	FILE *file;
+	char buffer[256];
+	
+	if ((file = fopen(filename, "rb")) != NULL) {
+		while (fgets(buffer, sizeof(buffer), file)) {
+			INSERT(buffer);
+		}
+		fclose(file);
+	}
+
+}
+
+static void quote_fmt_insert_program_output(const gchar *progname)
+{
+	FILE *file;
+	char buffer[256];
+
+	if ((file = popen(progname, "r")) != NULL) {
+		while (fgets(buffer, sizeof(buffer), file)) {
+			INSERT(buffer);
+		}
+		fclose(file);
+	}
+}
+
+
 
 /* Enabling traces.  */
 #ifndef YYDEBUG
@@ -283,13 +519,13 @@ static int isseparator(int ch)
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 148 "quote_fmt_parse.y"
+#line 384 "quote_fmt_parse.y"
 typedef union YYSTYPE {
 	char chr;
 	char str[256];
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 293 "quote_fmt_parse.c"
+#line 529 "quote_fmt_parse.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -301,7 +537,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 305 "quote_fmt_parse.c"
+#line 541 "quote_fmt_parse.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -497,12 +733,12 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned short int yyrline[] =
 {
-       0,   178,   178,   181,   182,   185,   186,   190,   191,   194,
-     198,   203,   211,   216,   278,   283,   288,   293,   322,   364,
-     391,   396,   401,   406,   410,   415,   420,   442,   466,   490,
-     516,   520,   524,   528,   532,   536,   540,   544,   551,   550,
-     559,   558,   567,   566,   575,   574,   583,   582,   591,   590,
-     599,   598,   607,   606,   615,   614,   624,   638
+       0,   414,   414,   417,   418,   421,   422,   426,   427,   430,
+     434,   439,   453,   458,   462,   467,   472,   477,   481,   485,
+     489,   494,   499,   504,   508,   513,   518,   522,   526,   530,
+     534,   538,   542,   546,   550,   554,   558,   562,   569,   568,
+     577,   576,   585,   584,   593,   592,   601,   600,   609,   608,
+     617,   616,   625,   624,   633,   632,   642,   646
 };
 #endif
 
@@ -1268,14 +1504,14 @@ yyreduce:
   switch (yyn)
     {
         case 6:
-#line 187 "quote_fmt_parse.y"
+#line 423 "quote_fmt_parse.y"
     {
 		INSERT_CHARACTER(yyvsp[0].chr);
 	}
     break;
 
   case 10:
-#line 199 "quote_fmt_parse.y"
+#line 435 "quote_fmt_parse.y"
     {
 		yyval.str[0] = yyvsp[0].chr;
 		yyval.str[1] = '\0';
@@ -1283,16 +1519,22 @@ yyreduce:
     break;
 
   case 11:
-#line 204 "quote_fmt_parse.y"
+#line 440 "quote_fmt_parse.y"
     {
-		strcpy(yyval.str, yyvsp[-1].str);
-		yyval.str[strlen(yyval.str) + 1] = '\0';
-		yyval.str[strlen(yyval.str)] = yyvsp[0].chr;
+		int len;
+		
+		strncpy(yyval.str, yyvsp[-1].str, sizeof(yyval.str));
+		yyval.str[sizeof(yyval.str) - 1] = '\0';
+		len = strlen(yyval.str);
+		if (len + 1 < sizeof(yyval.str)) {
+			yyval.str[len + 1] = '\0';
+			yyval.str[len] = yyvsp[0].chr;
+		}
 	}
     break;
 
   case 12:
-#line 212 "quote_fmt_parse.y"
+#line 454 "quote_fmt_parse.y"
     {
 		if (msginfo->newsgroups)
 			INSERT(msginfo->newsgroups);
@@ -1300,72 +1542,14 @@ yyreduce:
     break;
 
   case 13:
-#line 217 "quote_fmt_parse.y"
+#line 459 "quote_fmt_parse.y"
     {
-		/* 
-		 * ALF - GNU C's strftime() has a nice format specifier 
-		 * for time zone offset (%z). Non-standard however, so 
-		 * emulate it.
-		 */
-		if (msginfo->date) {
-			char  result[100];
-			char *rptr;
-			char  zone[6];
-			struct tm lt;
-			const char *fptr;
-			const char *zptr;
-
-#define RLEFT (sizeof result) - (rptr - result)	
-#define STR_SIZE(x) (sizeof (x) - 1)
-
-			zone[0] = 0;
-
-			if (procheader_date_parse_to_tm(msginfo->date, &lt, zone)) {
-				/*
-				 * break up format string in tiny bits delimited by valid %z's and 
-				 * feed it to strftime(). don't forget that '%%z' mean literal '%z'.
-				 */
-				for (rptr = result, fptr = yyvsp[-1].str; fptr && *fptr && rptr < &result[sizeof result - 1];) {
-					int	    perc;
-					const char *p;
-					char	   *tmp;
-					
-					if (NULL != (zptr = strstr(fptr, "%z"))) {
-						/*
-						 * count nr. of prepended percent chars
-						 */
-						for (perc = 0, p = zptr; p && p >= yyvsp[-1].str && *p == '%'; p--, perc++)
-							;
-						/*
-						 * feed to strftime()
-						 */
-						tmp = g_strndup(fptr, zptr - fptr + (perc % 2 ? 0 : STR_SIZE("%z")));
-						if (tmp) {
-							rptr += strftime(rptr, RLEFT, tmp, &lt);
-							g_free(tmp);
-						}
-						/*
-						 * append time zone offset
-						 */
-						if (zone[0] && perc % 2) 
-							rptr += g_snprintf(rptr, RLEFT, "%s", zone);
-						fptr = zptr + STR_SIZE("%z");
-					} else {
-						rptr += strftime(rptr, RLEFT, fptr, &lt);
-						fptr  = NULL;
-					}
-				}
-				
-				INSERT(result);
-			}
-#undef STR_SIZE			
-#undef RLEFT			
-		}
+		quote_fmt_show_date(msginfo, yyvsp[-1].str);
 	}
     break;
 
   case 14:
-#line 279 "quote_fmt_parse.y"
+#line 463 "quote_fmt_parse.y"
     {
 		if (msginfo->date)
 			INSERT(msginfo->date);
@@ -1373,7 +1557,7 @@ yyreduce:
     break;
 
   case 15:
-#line 284 "quote_fmt_parse.y"
+#line 468 "quote_fmt_parse.y"
     {
 		if (msginfo->from)
 			INSERT(msginfo->from);
@@ -1381,7 +1565,7 @@ yyreduce:
     break;
 
   case 16:
-#line 289 "quote_fmt_parse.y"
+#line 473 "quote_fmt_parse.y"
     {
 		if (msginfo->fromname)
 			INSERT(msginfo->fromname);
@@ -1389,114 +1573,28 @@ yyreduce:
     break;
 
   case 17:
-#line 294 "quote_fmt_parse.y"
+#line 478 "quote_fmt_parse.y"
     {
-		if (msginfo->fromname) {
-			guchar *p;
-			gchar *str;
-
-			p = strchr(msginfo->fromname, ',');
-			if (p != NULL) {
-				/* fromname is like "Duck, Donald" */
-				p++;
-				while (*p && isspace(*p)) p++;
-				str = alloca(strlen(p) + 1);
-				if (str != NULL) {
-					strcpy(str, p);
-					INSERT(str);
-				}
-			} else {
-				/* fromname is like "Donald Duck" */
-				str = alloca(strlen(msginfo->fromname) + 1);
-				if (str != NULL) {
-					strcpy(str, msginfo->fromname);
-					p = str;
-					while (*p && !isspace(*p)) p++;
-					*p = '\0';
-					INSERT(str);
-				}
-			}
-		}
+		quote_fmt_show_first_name(msginfo);
 	}
     break;
 
   case 18:
-#line 323 "quote_fmt_parse.y"
+#line 482 "quote_fmt_parse.y"
     {
-                /* This probably won't work together very well with Middle
-                 names and the like - thth */
-		if (msginfo->fromname) {
-			gchar *p;
-			gchar *str;
-
-			str = alloca(strlen(msginfo->fromname) + 1);
-			if (str != NULL) {
-				strcpy(str, msginfo->fromname);
-				p = strchr(str, ',');
-				if (p != NULL) {
-					/* fromname is like "Duck, Donald" */
-					*p = '\0';
-					INSERT(str);
-				} else {
-					/* fromname is like "Donald Duck" */
-					p = str;
-					while (*p && !isspace(*p)) p++;
-					if (*p) {
-					    /* We found a space. Get first 
-					     none-space char and insert
-					     rest of string from there. */
-					    while (*p && isspace(*p)) p++;
-					    if (*p) {
-						INSERT(p);
-					    } else {
-						/* If there is no none-space 
-						 char, just insert whole 
-						 fromname. */
-						INSERT(str);
-					    }
-					} else {
-					    /* If there is no space, just 
-					     insert whole fromname. */
-					    INSERT(str);
-					}
-				}
-			}
-		}
+		quote_fmt_show_last_name(msginfo);
 	}
     break;
 
   case 19:
-#line 365 "quote_fmt_parse.y"
+#line 486 "quote_fmt_parse.y"
     {
-#define MAX_SENDER_INITIAL 20
-		if (msginfo->fromname) {
-			gchar tmp[MAX_SENDER_INITIAL];
-			guchar *p;
-			gchar *cur;
-			gint len = 0;
-
-			p = msginfo->fromname;
-			cur = tmp;
-			while (*p) {
-				if (*p && isalnum(*p)) {
-					*cur = toupper(*p);
-						cur++;
-					len++;
-					if (len >= MAX_SENDER_INITIAL - 1)
-						break;
-				} else
-					break;
-				while (*p && !isseparator(*p)) p++;
-				while (*p && isseparator(*p)) p++;
-			}
-			*cur = '\0';
-			INSERT(tmp);
-		}
+		quote_fmt_show_sender_initial(msginfo);
 	}
     break;
 
   case 20:
-#line 392 "quote_fmt_parse.y"
+#line 490 "quote_fmt_parse.y"
     {
 		if (msginfo->subject)
 			INSERT(msginfo->subject);
@@ -1504,7 +1602,7 @@ yyreduce:
     break;
 
   case 21:
-#line 397 "quote_fmt_parse.y"
+#line 495 "quote_fmt_parse.y"
     {
 		if (msginfo->to)
 			INSERT(msginfo->to);
@@ -1512,7 +1610,7 @@ yyreduce:
     break;
 
   case 22:
-#line 402 "quote_fmt_parse.y"
+#line 500 "quote_fmt_parse.y"
     {
 		if (msginfo->msgid)
 			INSERT(msginfo->msgid);
@@ -1520,14 +1618,14 @@ yyreduce:
     break;
 
   case 23:
-#line 407 "quote_fmt_parse.y"
+#line 505 "quote_fmt_parse.y"
     {
 		INSERT("%");
 	}
     break;
 
   case 24:
-#line 411 "quote_fmt_parse.y"
+#line 509 "quote_fmt_parse.y"
     {
 		if (msginfo->cc)
 			INSERT(msginfo->cc);
@@ -1535,7 +1633,7 @@ yyreduce:
     break;
 
   case 25:
-#line 416 "quote_fmt_parse.y"
+#line 514 "quote_fmt_parse.y"
     {
 		/* if (msginfo->references)
 			INSERT(msginfo->references); */
@@ -1543,326 +1641,226 @@ yyreduce:
     break;
 
   case 26:
-#line 421 "quote_fmt_parse.y"
+#line 519 "quote_fmt_parse.y"
     {
-		if (msginfo->folder || body) {
-			gchar buf[BUFFSIZE];
-			FILE *fp;
-
-			if (body)
-				fp = str_open_as_stream(body);
-			else
-				fp = procmime_get_first_text_content(msginfo);
-
-			if (fp == NULL)
-				g_warning("Can't get text part\n");
-			else {
-				while (fgets(buf, sizeof(buf), fp) != NULL) {
-					strcrchomp(buf);
-					INSERT(buf);
-				}
-				fclose(fp);
-			}
-		}
+		quote_fmt_show_msg(msginfo, body, FALSE, TRUE, quote_str);
 	}
     break;
 
   case 27:
-#line 443 "quote_fmt_parse.y"
+#line 523 "quote_fmt_parse.y"
     {
-		if (msginfo->folder || body) {
-			gchar buf[BUFFSIZE];
-			FILE *fp;
-
-			if (body)
-				fp = str_open_as_stream(body);
-			else
-				fp = procmime_get_first_text_content(msginfo);
-
-			if (fp == NULL)
-				g_warning("Can't get text part\n");
-			else {
-				while (fgets(buf, sizeof(buf), fp) != NULL) {
-					strcrchomp(buf);
-					if (quote_str)
-						INSERT(quote_str);
-					INSERT(buf);
-				}
-				fclose(fp);
-			}
-		}
+		quote_fmt_show_msg(msginfo, body, TRUE, TRUE, quote_str);
 	}
     break;
 
   case 28:
-#line 467 "quote_fmt_parse.y"
+#line 527 "quote_fmt_parse.y"
     {
-		if (msginfo->folder || body) {
-			gchar buf[BUFFSIZE];
-			FILE *fp;
-
-			if (body)
-				fp = str_open_as_stream(body);
-			else
-				fp = procmime_get_first_text_content(msginfo);
-
-			if (fp == NULL)
-				g_warning("Can't get text part\n");
-			else {
-				while (fgets(buf, sizeof(buf), fp) != NULL) {
-					strcrchomp(buf);
-					if (strncmp(buf, "-- \n", 4) == 0)
-						break;
-					INSERT(buf);
-				}
-				fclose(fp);
-			}
-		}
+		quote_fmt_show_msg(msginfo, body, FALSE, FALSE, quote_str);
 	}
     break;
 
   case 29:
-#line 491 "quote_fmt_parse.y"
+#line 531 "quote_fmt_parse.y"
     {
-		if (msginfo->folder || body) {
-			gchar buf[BUFFSIZE];
-			FILE *fp;
-
-			if (body)
-				fp = str_open_as_stream(body);
-			else
-				fp = procmime_get_first_text_content(msginfo);
-
-			if (fp == NULL)
-				g_warning("Can't get text part\n");
-			else {
-				while (fgets(buf, sizeof(buf), fp) != NULL) {
-					strcrchomp(buf);
-					if (strncmp(buf, "-- \n", 4) == 0)
-						break;
-					if (quote_str)
-						INSERT(quote_str);
-					INSERT(buf);
-				}
-				fclose(fp);
-			}
-		}
+		quote_fmt_show_msg(msginfo, body, TRUE, FALSE, quote_str);
 	}
     break;
 
   case 30:
-#line 517 "quote_fmt_parse.y"
+#line 535 "quote_fmt_parse.y"
     {
 		INSERT("\\");
 	}
     break;
 
   case 31:
-#line 521 "quote_fmt_parse.y"
+#line 539 "quote_fmt_parse.y"
     {
 		INSERT("\t");
 	}
     break;
 
   case 32:
-#line 525 "quote_fmt_parse.y"
+#line 543 "quote_fmt_parse.y"
     {
 		INSERT("\n");
 	}
     break;
 
   case 33:
-#line 529 "quote_fmt_parse.y"
+#line 547 "quote_fmt_parse.y"
     {
 		INSERT("?");
 	}
     break;
 
   case 34:
-#line 533 "quote_fmt_parse.y"
+#line 551 "quote_fmt_parse.y"
     {
 		INSERT("|");
 	}
     break;
 
   case 35:
-#line 537 "quote_fmt_parse.y"
+#line 555 "quote_fmt_parse.y"
     {
 		INSERT("{");
 	}
     break;
 
   case 36:
-#line 541 "quote_fmt_parse.y"
+#line 559 "quote_fmt_parse.y"
     {
 		INSERT("}");
 	}
     break;
 
   case 37:
-#line 545 "quote_fmt_parse.y"
+#line 563 "quote_fmt_parse.y"
     {
 		cursor_pos = bufsize;
 	}
     break;
 
   case 38:
-#line 551 "quote_fmt_parse.y"
+#line 569 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->date != NULL);
 	}
     break;
 
   case 39:
-#line 555 "quote_fmt_parse.y"
+#line 573 "quote_fmt_parse.y"
     {
 		remove_visibility();
 	}
     break;
 
   case 40:
-#line 559 "quote_fmt_parse.y"
+#line 577 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->from != NULL);
 	}
     break;
 
   case 41:
-#line 563 "quote_fmt_parse.y"
+#line 581 "quote_fmt_parse.y"
     {
 		remove_visibility();
 	}
     break;
 
   case 42:
-#line 567 "quote_fmt_parse.y"
+#line 585 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->fromname != NULL);
 	}
     break;
 
   case 43:
-#line 571 "quote_fmt_parse.y"
+#line 589 "quote_fmt_parse.y"
     {
 		remove_visibility();
 	}
     break;
 
   case 44:
-#line 575 "quote_fmt_parse.y"
+#line 593 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->subject != NULL);
 	}
     break;
 
   case 45:
-#line 579 "quote_fmt_parse.y"
+#line 597 "quote_fmt_parse.y"
     {
 		remove_visibility();
 	}
     break;
 
   case 46:
-#line 583 "quote_fmt_parse.y"
+#line 601 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->to != NULL);
 	}
     break;
 
   case 47:
-#line 587 "quote_fmt_parse.y"
+#line 605 "quote_fmt_parse.y"
     {
 		remove_visibility();
 	}
     break;
 
   case 48:
-#line 591 "quote_fmt_parse.y"
+#line 609 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->newsgroups != NULL);
 	}
     break;
 
   case 49:
-#line 595 "quote_fmt_parse.y"
+#line 613 "quote_fmt_parse.y"
     {
 		remove_visibility();
 	}
     break;
 
   case 50:
-#line 599 "quote_fmt_parse.y"
+#line 617 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->msgid != NULL);
 	}
     break;
 
   case 51:
-#line 603 "quote_fmt_parse.y"
+#line 621 "quote_fmt_parse.y"
     {
 		remove_visibility();
 	}
     break;
 
   case 52:
-#line 607 "quote_fmt_parse.y"
+#line 625 "quote_fmt_parse.y"
     {
 		add_visibility(msginfo->cc != NULL);
 	}
     break;
 
   case 53:
-#line 611 "quote_fmt_parse.y"
+#line 629 "quote_fmt_parse.y"
     {
 		remove_visibility();
 	}
     break;
 
   case 54:
-#line 615 "quote_fmt_parse.y"
+#line 633 "quote_fmt_parse.y"
     {
 		/* add_visibility(msginfo->references != NULL); */
 	}
     break;
 
   case 55:
-#line 619 "quote_fmt_parse.y"
+#line 637 "quote_fmt_parse.y"
     {
 		remove_visibility();
 	}
     break;
 
   case 56:
-#line 625 "quote_fmt_parse.y"
+#line 643 "quote_fmt_parse.y"
     {
-		{
-			FILE *file;
-			char buffer[256];
-			
-			if((file = fopen(yyvsp[-1].str, "rb")) != NULL) {
-				while(fgets(buffer, sizeof(buffer), file)) {
-					INSERT(buffer);
-				}
-				fclose(file);
-			}
-		}
+		quote_fmt_insert_file(yyvsp[-1].str);
 	}
     break;
 
   case 57:
-#line 639 "quote_fmt_parse.y"
+#line 647 "quote_fmt_parse.y"
     {
-		{
-			FILE *file;
-			char buffer[256];
-
-			if((file = popen(yyvsp[-1].str, "r")) != NULL) {
-				while(fgets(buffer, sizeof(buffer), file)) {
-					INSERT(buffer);
-				}
-				fclose(file);
-			}
-		}
+		quote_fmt_insert_program_output(yyvsp[-1].str);
 	}
     break;
 
@@ -1870,7 +1868,7 @@ yyreduce:
     }
 
 /* Line 1010 of yacc.c.  */
-#line 1874 "quote_fmt_parse.c"
+#line 1872 "quote_fmt_parse.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
